==> webkit2gtk_2.38.6.orig.tar.xz: webkitgtk-2.38.6/Source/WebKit/Shared/WebGPU/WebGPUColorTargetState.cpp <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUColorTargetState.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <pal/graphics/WebGPU/WebGPUColorTargetState.h>

namespace WebKit::WebGPU {

std::optional<ColorTargetState> ConvertToBackingContext::convertToBacking(const PAL::WebGPU::ColorTargetState& colorTargetState)
{
    std::optional<BlendState> blend;
    if (colorTargetState.blend) {
        blend = convertToBacking(*colorTargetState.blend);
        if (!blend)
            return std::nullopt;
    }

    return { { colorTargetState.format, WTFMove(blend), colorTargetState.writeMask } };
}

std::optional<PAL::WebGPU::ColorTargetState> ConvertFromBackingContext::convertFromBacking(const ColorTargetState& colorTargetState)
{
    std::optional<PAL::WebGPU::BlendState> blend;
    if (colorTargetState.blend) {
        blend = convertFromBacking(*colorTargetState.blend);
        if (!blend)
            return std::nullopt;
    }

    return { { colorTargetState.format, WTFMove(blend), colorTargetState.writeMask } };
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebKit/Shared/WebGPU/WebGPUColorTargetState.cpp <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUColorTargetState.h"

#if ENABLE(GPU_PROCESS)

#include "WebGPUConvertFromBackingContext.h"
#include "WebGPUConvertToBackingContext.h"
#include <WebCore/WebGPUColorTargetState.h>

namespace WebKit::WebGPU {

std::optional<ColorTargetState> ConvertToBackingContext::convertToBacking(const WebCore::WebGPU::ColorTargetState& colorTargetState)
{
    std::optional<BlendState> blend;
    if (colorTargetState.blend) {
        blend = convertToBacking(*colorTargetState.blend);
        if (!blend)
            return std::nullopt;
    }

    return { { colorTargetState.format, WTFMove(blend), colorTargetState.writeMask } };
}

std::optional<WebCore::WebGPU::ColorTargetState> ConvertFromBackingContext::convertFromBacking(const ColorTargetState& colorTargetState)
{
    std::optional<WebCore::WebGPU::BlendState> blend;
    if (colorTargetState.blend) {
        blend = convertFromBacking(*colorTargetState.blend);
        if (!blend)
            return std::nullopt;
    }

    return { { colorTargetState.format, WTFMove(blend), colorTargetState.writeMask } };
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS)
